#!/bin/bash -e
#
# prepare-raspbian-sd:bin/prepare-raspbian-config-api.sh
#
declare -gr PREPARE_RASPBIAN_CONFIG="${HOME}/.config/prepare-raspbian-sd"
declare -gr PREPARE_RASPBIAN_CONFIG_VARS_LIST='DEFAULT_SD_DEV_NAME
GPU_MEM
RASPBIAN_DEFAULT_BACKUP_DIRECTORY
RASPBIAN_DEFAULT_DOWNLOAD_IMAGE_DIRECTORY
RASPBIAN_DEFAULT_IMG
SSH_AUTHORIZED_KEYS'

function prepare_raspbian_config_is_var_name_valide {
  local -r varname="$1"
  local    var=

  while read -r var ; do
   if [ "${varname}" = "${var}" ] ; then
    return 0
   fi
  done <<<"${PREPARE_RASPBIAN_CONFIG_VARS_LIST}"

  return 1
}

function prepare_raspbian_config_set {
  local -r varname="$1"
  local -r var_value="$2"

  if [ ! -d "${PREPARE_RASPBIAN_CONFIG}" ] ; then
    mkdir -vp "${PREPARE_RASPBIAN_CONFIG}"
  fi

  exit_if_directory_not_exists "${PREPARE_RASPBIAN_CONFIG}"

  if [ -n "${var_value}" ] ; then
    echo "${var_value}" >"${PREPARE_RASPBIAN_CONFIG}/${varname}" || exit 1
    echoinfo "'${varname}' is set to '${var_value}'"
  else
    if [ -f "${PREPARE_RASPBIAN_CONFIG}/${varname}" ] ; then
      rm "${PREPARE_RASPBIAN_CONFIG}/${varname}" || exit 1
    fi
    echoinfo "'${varname}' is removed."
  fi
}

function prepare_raspbian_initialise_if_needed {
  local -r varname="$1"
  local -r default_value="${2:-}"

  if ! is_variable_define_and_not_empty_safe "${varname}" ; then
    if [ -f "${PREPARE_RASPBIAN_CONFIG}/${varname}" ] ; then
      declare "${varname}"="$( <"${PREPARE_RASPBIAN_CONFIG}/${varname}" )"
    fi

    if ! is_variable_define_and_not_empty_safe "${varname}" ; then
      if [ -n "${default_value}" ] ; then
        echowarn "${varname} is not define" >&2
        declare "${varname}"="${default_value}"
        echowarn "Use ${varname}=${!varname}" >&2
      fi
    fi

    if is_variable_define_and_not_empty_safe "${varname}" ; then
      declare -gr "${varname}=${!varname}"
      # shellcheck disable=SC2163
      export "${varname}"
    fi
  fi
}
