#!/bin/bash
#
# prepare-raspbian-sd:bin/prepare-raspbian-sd-config.sh
#
set -u
set -o pipefail

PROJECT_HOME="$( dirname "$( dirname "$( realpath "${BASH_SOURCE[0]}" )" )" )"
declare -gr PROJECT_HOME

# shellcheck disable=SC1090
source "${PROJECT_HOME}/apis/bash-common-api/bash-common-api.sh" || exit 1
# shellcheck disable=SC1090
source "${PROJECT_HOME}/bin/prepare-raspbian-config-api.sh" || exit 1

function usage {
  cat <<EOF
Usage: $0

   $( basename "$0" ) --help
   $( basename "$0" ) --list
   $( basename "$0" ) --get VARNAME
   $( basename "$0" ) [--set] VARNAME [VALUE]

Allow to configure prepare-raspbian-sd default values.

Actions:
  -h, --help                Display help message and exit.
  -l, --list                Display valid variables name's
  -A, --all, --list-all     Show all define variables
      --set VARNAME [VALUE] Set given variable to VALUE if define, remove
                            variable if not.
      --get VARNAME         Show given variable content

EOF
}

function exit_if_name_not_valid {
  local -r var_name="$1"

  if ! prepare_raspbian_config_is_var_name_valide "${var_name}" ; then
    echofatal "What is '${var_name}' ?"
    usage >&2
    exit 1
  fi
}

function set_value {
  if [ $# -gt 2 ] ; then
    echofatal 'Too much values.'
    usage >&2
    exit 1
  fi

  local var_name="$1"

  exit_if_name_not_valid "${var_name}"
  prepare_raspbian_config_set "${var_name}" "${2:-}"
}

function get_value {
  if [ $# -gt 1 ] ; then
    echofatal 'Too much values.'
    usage >&2
    exit 1
  fi

  local -r var_name="$1"

  exit_if_name_not_valid "${var_name}"
  prepare_raspbian_initialise_if_needed "${var_name}"

  if is_variable_define_and_not_empty_safe "${var_name}" ; then
    echo "${var_name}=${!var_name}"
  else
    echo "${var_name} not define"
  fi
}

function show_list {
  echo "${PREPARE_RASPBIAN_CONFIG_VARS_LIST}"
}

function show_list_all {
  local var=

  while read -r var ; do
    get_value "${var}"
  done <<<"${PREPARE_RASPBIAN_CONFIG_VARS_LIST}"
}


function main {
  if [ $# -eq 0 ] ; then
    echofatal 'Parameters missing.'
    usage >&2
    exit 1
  fi

  local param="$1"
  shift

  case "${param}" in
    '-h'|'--help')
      usage
      exit 0
      ;;

    '-l'|'--list')
      show_list
      exit 0
      ;;

    '-A'|'--all'|'--list-all')
      show_list_all
      exit 0
      ;;

    '--set')
      set_value "$@"
      ;;

    '--get')
      get_value "$@"
      ;;

    *)
      set_value "${param}" "$@"
  esac
}

main "$@"
